@@ -2,7 +2,7 @@ package Dezi;
 use warnings;
 use strict;
 
-our $VERSION = '0.001006';
+our $VERSION = '0.001007';
 
 1;
 
@@ -10,7 +10,7 @@ __END__
 
 =head1 NAME
 
-Dezi - search platform based on Apache Lucy, Swish3, Search::OpenSearch and Plack
+Dezi - REST search platform
 
 =head1 SYNOPSIS
 
@@ -26,8 +26,8 @@ Add a document B<foo> to the index:
    
 Search the index:
 
- % curl 'http://localhost:5000/search?q=bar&format=json'
- % curl 'http://localhost:5000/search?q=bar&format=xml'
+ % curl 'http://localhost:5000/search?q=bar&t=JSON'
+ % curl 'http://localhost:5000/search?q=bar&t=XML'
 
 =head1 DESCRIPTION
 
@@ -37,10 +37,42 @@ Search::OpenSearch and Search::Query.
 Dezi integrates several CPAN search libraries into one
 easy-to-use interface.
 
+This document is a placeholder for the namespace and documentation
+only. You should read:
+
+=over
+
+=item
+
+the L<Dezi::Tutorial>
+
+=item
+
+the L<Dezi::Server> class documentation
+
+=item
+
+the L<dezi> command line tool perldoc, which includes details
+about the configuration file format.
+
+=item
+
+the L<Search::OpenSearch::Server::Plack> documentation, upon which
+Dezi relies heavily.
+
+=back
+
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
 
+=head1 ACKNOWLEDGEMENTS
+
+Much of the code upon which Dezi relies
+was originally developed for the 
+Public Insight Network at American Public Media.
+L<http://www.publicinsightnetwork.org>.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi at rt.cpan.org>, or through
@@ -58,6 +90,14 @@ You can also look for information at:
 
 =over 4
 
+=item * Website
+
+L<http://dezi.org/>
+
+=item * IRC
+
+#dezisearch at freenode
+
 =item * Mailing list
 
 L<https://groups.google.com/forum/#!forum/dezi-search>
@@ -93,6 +133,6 @@ See http://dev.perl.org/licenses/ for more information.
 =head1 SEE ALSO
 
 L<Search::OpenSearch>, L<SWISH::3>, L<SWISH::Prog::Lucy>,
-L<Plack>, L<Lucy>
+L<Plack>, L<Lucy>, L<http://dezi.org>
 
 =cut
