@@ -6,7 +6,7 @@ use Plack::Builder;
 use base 'Search::OpenSearch::Server::Plack';
 use Dezi::Server::About;
 
-our $VERSION = '0.001006';
+our $VERSION = '0.001007';
 
 sub new {
     my ( $class, %args ) = @_;
@@ -125,8 +125,8 @@ Add a document B<foo> to the index:
    
 Search the index:
 
- % curl 'http://localhost:5000/search?q=bar&format=json'
- % curl 'http://localhost:5000/search?q=bar&format=xml'
+ % curl 'http://localhost:5000/search?q=bar&t=JSON'
+ % curl 'http://localhost:5000/search?q=bar&t=XML'
 
 =head1 DESCRIPTION
 
@@ -136,6 +136,9 @@ Search::OpenSearch and Search::Query.
 Dezi integrates several CPAN search libraries into one
 easy-to-use interface.
 
+Be sure to read the perldoc for L<Search::OpenSearch::Engine>
+and L<Search::OpenSearch::Server::Plack>.
+
 =head1 METHODS
 
 Dezi::Server is a subclass of Search::OpenSearch::Server::Plack.
