@@ -5,7 +5,7 @@ use Carp;
 use JSON;
 use Search::Tools::XML;
 
-our $VERSION = '0.001006';
+our $VERSION = '0.001007';
 
 sub new {
     my $class       = shift;
@@ -53,41 +53,41 @@ sub new {
     my $about = {
         name         => 'Dezi',
         author       => 'Peter Karman <karpet@dezi.org>',
-        api_base_url => $uri,
+        api_base_url => "$uri",
         api_format   => [qw( JSON ExtJS XML )],
         methods      => [
             {   method      => 'GET',
-                path        => $search_path,
+                path        => "$search_path",
                 params      => [qw( q r c f o s p t u)],
                 required    => [qw( q )],
                 description => 'return search results',
-                base_url    => $search_uri,
+                base_url    => "$search_uri",
             },
             {   method      => 'POST',
-                path        => $index_path . '/:doc_uri',
+                path        => "$index_path" . '/:doc_uri',
                 params      => [],
                 required    => [],
                 description => 'update the index with content for doc_uri',
-                base_url    => $index_uri,
+                base_url    => "$index_uri",
             },
             {   method      => 'PUT',
-                path        => $index_path . '/:doc_uri',
+                path        => "$index_path" . '/:doc_uri',
                 params      => [],
                 required    => [],
                 description => 'update the index with content for doc_uri',
-                base_url    => $index_uri,
+                base_url    => "$index_uri",
             },
             {   method      => 'DELETE',
-                path        => $index_path . '/:doc_uri',
+                path        => "$index_path" . '/:doc_uri',
                 params      => [],
                 required    => [],
                 description => 'remove doc_uri from the index',
-                base_url    => $index_uri,
+                base_url    => "$index_uri",
             },
         ],
         engine => ref( $server->engine ),
-        search => $search_uri,
-        index  => $index_uri,
+        search => "$search_uri",
+        index  => "$index_uri",
         description =>
             'This is a Dezi search server. See http://dezi.org/ for more details.',
         version => $version,
